# `dataparsers`

This project provides a simple module that wrappers around
[`argparse`](https://docs.python.org/3/library/argparse.html#module-argparse) to
get command line argument parsers from
[`dataclasses`](https://docs.python.org/3/library/dataclasses.html#module-dataclasses).

## Installation

```bash
pip install dataparsers
```

```{toctree}
:caption: Table of contents
:maxdepth: 1

1_user_manual
2_available_functions
3_features
```

## Links

- GitHub repository:
  [https://github.com/diogo-rossi/dataparsers](https://github.com/diogo-rossi/dataparsers)
- PyPI:
  [https://pypi.org/project/dataparsers/](https://pypi.org/project/dataparsers/)
- Documentation:
  [https://dataparsers.readthedocs.io/en/latest/](https://dataparsers.readthedocs.io/en/latest/)
